package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.TSosSolveMapper;
import com.ruoyi.system.domain.TSosSolve;
import com.ruoyi.system.service.ITSosSolveService;

/**
 * SOS预警处理Service业务层处理
 * 
 * @author zhengjie
 * @date 2023-09-08
 */
@Service
public class TSosSolveServiceImpl implements ITSosSolveService 
{
    @Autowired
    private TSosSolveMapper tSosSolveMapper;

    /**
     * 查询SOS预警处理
     * 
     * @param id SOS预警处理主键
     * @return SOS预警处理
     */
    @Override
    public TSosSolve selectTSosSolveById(Integer id)
    {
        return tSosSolveMapper.selectTSosSolveById(id);
    }

    /**
     * 查询SOS预警处理列表
     * 
     * @param tSosSolve SOS预警处理
     * @return SOS预警处理
     */
    @Override
    public List<TSosSolve> selectTSosSolveList(TSosSolve tSosSolve)
    {
        return tSosSolveMapper.selectTSosSolveList(tSosSolve);
    }

    /**
     * 新增SOS预警处理
     * 
     * @param tSosSolve SOS预警处理
     * @return 结果
     */
    @Override
    public int insertTSosSolve(TSosSolve tSosSolve)
    {
        tSosSolve.setCreateTime(DateUtils.getNowDate());
        return tSosSolveMapper.insertTSosSolve(tSosSolve);
    }

    /**
     * 修改SOS预警处理
     * 
     * @param tSosSolve SOS预警处理
     * @return 结果
     */
    @Override
    public int updateTSosSolve(TSosSolve tSosSolve)
    {
        return tSosSolveMapper.updateTSosSolve(tSosSolve);
    }

    /**
     * 批量删除SOS预警处理
     * 
     * @param ids 需要删除的SOS预警处理主键
     * @return 结果
     */
    @Override
    public int deleteTSosSolveByIds(Integer[] ids)
    {
        return tSosSolveMapper.deleteTSosSolveByIds(ids);
    }

    /**
     * 删除SOS预警处理信息
     * 
     * @param id SOS预警处理主键
     * @return 结果
     */
    @Override
    public int deleteTSosSolveById(Integer id)
    {
        return tSosSolveMapper.deleteTSosSolveById(id);
    }
}
